@@ -3,6 +3,11 @@ from i3pystatus.file import File
 class Backlight(File):
     """
     Screen backlight info
+
+    Available formatters:
+    * `{brightness}` — current brightness relative to max_brightness
+    * `{max_brightness}` — maximum brightness value
+    * `{percentage}` — current brightness in percent
     """
 
     settings = (
